@@ -26,7 +26,7 @@
 #include "acb.h"
 
 void
-acb_arg(arb_t r, const acb_t z, long prec)
+acb_arg(arb_t r, const acb_t z, slong prec)
 {
     arb_atan2(r, acb_imagref(z), acb_realref(z), prec);
 }
