@@ -26,7 +26,7 @@
 #include "acb_hypgeom.h"
 
 void
-acb_hypgeom_erfi(acb_t res, const acb_t z, long prec)
+acb_hypgeom_erfi(acb_t res, const acb_t z, slong prec)
 {
     acb_mul_onei(res, z);
     acb_hypgeom_erf(res, res, prec);
